==> redux-0.2.0.tgz: package/lib/performs.js <==
'use strict';

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _get = require('babel-runtime/helpers/get')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _slicedToArray = require('babel-runtime/helpers/sliced-to-array')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

exports['default'] = performs;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _lodashObjectPick = require('lodash/object/pick');

var _lodashObjectPick2 = _interopRequireDefault(_lodashObjectPick);

var _lodashUtilityIdentity = require('lodash/utility/identity');

var _lodashUtilityIdentity2 = _interopRequireDefault(_lodashUtilityIdentity);

var contextTypes = {
  getActions: _react.PropTypes.func.isRequired
};

function performs() {
  for (var _len = arguments.length, actionKeys = Array(_len), _key = 0; _key < _len; _key++) {
    actionKeys[_key] = arguments[_key];
  }

  var mapActions = _lodashUtilityIdentity2['default'];

  // Last argument may be a custom mapState function
  var lastIndex = actionKeys.length - 1;
  if (typeof actionKeys[lastIndex] === 'function') {
    var _actionKeys$splice = actionKeys.splice(lastIndex, 1);

    var _actionKeys$splice2 = _slicedToArray(_actionKeys$splice, 1);

    mapActions = _actionKeys$splice2[0];
  }

  return function (DecoratedComponent) {
    var wrappedDisplayName = DecoratedComponent.displayName || DecoratedComponent.name || 'Component';

    return (function (_Component) {
      var _class = function (props, context) {
        _classCallCheck(this, _class);

        _get(Object.getPrototypeOf(_class.prototype), 'constructor', this).call(this, props, context);
        this.updateActions(props);
      };

      _inherits(_class, _Component);

      _createClass(_class, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
          this.updateActions(nextProps);
        }
      }, {
        key: 'updateActions',
        value: function updateActions(props) {
          this.actions = mapActions((0, _lodashObjectPick2['default'])(this.context.getActions(), actionKeys), props);
        }
      }, {
        key: 'render',
        value: function render() {
          return _react2['default'].createElement(DecoratedComponent, this.actions);
        }
      }], [{
        key: 'displayName',
        value: 'ReduxPerforms(' + wrappedDisplayName + ')',
        enumerable: true
      }, {
        key: 'contextTypes',
        value: contextTypes,
        enumerable: true
      }]);

      return _class;
    })(_react.Component);
  };
}

module.exports = exports['default'];

==> redux-0.3.0.tgz: package/lib/performs.js <==
'use strict';

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _get = require('babel-runtime/helpers/get')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _slicedToArray = require('babel-runtime/helpers/sliced-to-array')['default'];

var _extends = require('babel-runtime/helpers/extends')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

exports['default'] = performs;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _lodashObjectPick = require('lodash/object/pick');

var _lodashObjectPick2 = _interopRequireDefault(_lodashObjectPick);

var _lodashUtilityIdentity = require('lodash/utility/identity');

var _lodashUtilityIdentity2 = _interopRequireDefault(_lodashUtilityIdentity);

var contextTypes = {
  getActions: _react.PropTypes.func.isRequired
};

function performs() {
  for (var _len = arguments.length, actionKeys = Array(_len), _key = 0; _key < _len; _key++) {
    actionKeys[_key] = arguments[_key];
  }

  var mapActions = _lodashUtilityIdentity2['default'];

  // Last argument may be a custom mapState function
  var lastIndex = actionKeys.length - 1;
  if (typeof actionKeys[lastIndex] === 'function') {
    var _actionKeys$splice = actionKeys.splice(lastIndex, 1);

    var _actionKeys$splice2 = _slicedToArray(_actionKeys$splice, 1);

    mapActions = _actionKeys$splice2[0];
  }

  return function (DecoratedComponent) {
    var wrappedDisplayName = DecoratedComponent.displayName || DecoratedComponent.name || 'Component';

    return (function (_Component) {
      var _class = function (props, context) {
        _classCallCheck(this, _class);

        _get(Object.getPrototypeOf(_class.prototype), 'constructor', this).call(this, props, context);
        this.updateActions(props);
      };

      _inherits(_class, _Component);

      _createClass(_class, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
          this.updateActions(nextProps);
        }
      }, {
        key: 'updateActions',
        value: function updateActions(props) {
          this.actions = mapActions((0, _lodashObjectPick2['default'])(this.context.getActions(), actionKeys), props);
        }
      }, {
        key: 'render',
        value: function render() {
          return _react2['default'].createElement(DecoratedComponent, _extends({}, this.props, this.actions));
        }
      }], [{
        key: 'displayName',
        value: 'ReduxPerforms(' + wrappedDisplayName + ')',
        enumerable: true
      }, {
        key: 'contextTypes',
        value: contextTypes,
        enumerable: true
      }]);

      return _class;
    })(_react.Component);
  };
}

module.exports = exports['default'];
